#Pacakge For Shivansh
#Nothing much is here
totalinfo = """My Name:- Shivansh
Age:- Who are You to see my Age
Class:- Why will I Tell you
My Fav Language:- MotherToungue, English, Hindi
My Hobby:- Programming // Hacking"""
name = "SHIVANSH"
hobby = "Programming // Hacking"
contact = "https://t.me/Ryoishin"
__version__ = "v0.0.2"
# Full Credit Gose To Sipak Bro 
